/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.head;

import java.util.Collections;

import org.apache.wicket.request.Response;

/**
 * {@link HeaderItem} that is not rendered.
 * 
 * @author papegaaij
 */
public class NoHeaderItem extends HeaderItem
{
	private static final NoHeaderItem INSTANCE = new NoHeaderItem();

	/**
	 * @return The singleton instance of {@code NoHeaderItem}
	 */
	public static NoHeaderItem get()
	{
		return INSTANCE;
	}

	@Override
	public void render(Response response)
	{
	}

	@Override
	public Iterable<?> getRenderTokens()
	{
		return Collections.emptyList();
	}
}
